# message-channel

![PyPI](https://img.shields.io/pypi/v/python-message-channel)
![PyPI - License](https://img.shields.io/pypi/l/python-message-channel)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/python-message-channel)
![Test](https://github.com/fixpoint/python-message-channel/workflows/Test/badge.svg)

**UNDER DEVELOPMENT**
